@@ -1,35 +1,72 @@
 from dockitcms.models import ViewPoint, Collection
-from dockitcms.viewpoints.common import AuthenticatedMixin, CanonicalMixin, TEMPLATE_SOURCE_CHOICES
+from dockitcms.viewpoints.common import CanonicalMixin, TEMPLATE_SOURCE_CHOICES
+from dockitcms.scope import Scope
 #from schema.forms import DocumentForm
 
 from django.conf.urls.defaults import patterns, url
 #from django import forms
 #from django.template import Template, TemplateSyntaxError
 from django.utils.translation import ugettext_lazy as _
+from django.utils.safestring import mark_safe
 
 from common import PointListView, PointDetailView, CollectionFilter, index_for_filters
 
 from dockit import schema
 
-class CategoryDetailView(PointDetailView): #TODO turn into list view, category=category, object_list=item_list
+class CategoryDetailView(PointListView):
     items_for_category_index = None
     item_category_dot_path = None
+    category = None
+    slug_field = None
+    
+    
+    def get_category(self):
+        if not self.category:
+            if 'slug' in self.kwargs:
+                self.category = self.document.objects.get(**{self.slug_field:self.kwargs['slug']})
+            else:
+                self.category = self.document.objects.get(pk=self.kwargs['pk'])
+        return self.category
+    
+    def get_queryset(self):
+        category = self.get_category()
+        return self.items_for_category_index.filter(**{self.item_category_dot_path: category.pk})
     
     def get_context_data(self, **kwargs):
         context = super(CategoryDetailView, self).get_context_data(**kwargs)
-        context['item_list'] = self.items_for_category_index.filter(**{self.item_category_dot_path: self.object.pk})
+        context['category'] = self.get_category()
         return context
+    
+    def get_scopes(self):
+        scopes = super(PointListView, self).get_scopes()
+        category = self.get_category()
+        object_scope = Scope('object', object=category)
+        object_scope.add_data('object', category, category.get_manage_urls())
+        scopes.append(object_scope)
+        return scopes
 
 class ItemDetailView(PointDetailView):
     pass
 
-class CategoryViewPoint(CanonicalMixin, ViewPoint):
+CATEGORY_CONTEXT_DESCRIPTION = mark_safe('''
+Context:<br/>
+<em>category</em> <span>The category object</span><br/>
+<em>object_list</em> <span>The list of items belonging to the category</span>
+
+''')
+
+ITEM_CONTEXT_DESCRIPTION = mark_safe('''
+Context: <br/>
+<em>object</em> <span>The item object</span>
+''')
+
+class CategoryViewPoint(ViewPoint, CanonicalMixin):
     category_collection = schema.ReferenceField(Collection)
     category_slug_field = schema.CharField(blank=True)
     category_template_source = schema.CharField(choices=TEMPLATE_SOURCE_CHOICES, default='name')
     category_template_name = schema.CharField(default='dockitcms/detail.html', blank=True)
     category_template_html = schema.TextField(blank=True)
-    category_content = schema.TextField(blank=True)
+    category_content = schema.TextField(blank=True, help_text=CATEGORY_CONTEXT_DESCRIPTION)
     category_filters = schema.ListField(schema.SchemaField(CollectionFilter), blank=True)
     
     item_collection = schema.ReferenceField(Collection)
@@ -38,7 +75,7 @@ class CategoryViewPoint(CanonicalMixin, ViewPoint):
     item_template_source = schema.CharField(choices=TEMPLATE_SOURCE_CHOICES, default='name')
     item_template_name = schema.CharField(default='dockitcms/detail.html', blank=True)
     item_template_html = schema.TextField(blank=True)
-    item_content = schema.TextField(blank=True)
+    item_content = schema.TextField(blank=True, help_text=ITEM_CONTEXT_DESCRIPTION)
     item_filters = schema.ListField(schema.SchemaField(CollectionFilter), blank=True)
     
     category_view_class = CategoryDetailView
@@ -82,7 +119,8 @@ class CategoryViewPoint(CanonicalMixin, ViewPoint):
             return view_point.reverse('category-detail', instance.pk)
         
         if self.canonical:
-            doc_cls.get_absolute_url = get_absolute_url_for_instance
+            setattr(doc_cls, 'get_absolute_url', get_absolute_url_for_instance)
+            #doc_cls.get_absolute_url = get_absolute_url_for_instance
         
         class WrappedDoc(doc_cls):
             get_absolute_url = get_absolute_url_for_instance
